.. coldsweet documentation master file, created by
   sphinx-quickstart on Wed Aug 21 22:26:25 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to coldsweet's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   setup
   using-with-nginx
   fetcher-features


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
